@@ -71,9 +71,8 @@ pub(crate) fn byte_encode(d: u32, integers_f: &[Z; 256], bytes_b: &mut [u8]) {
 ///
 /// Input: byte array `B ∈ B^{32·d}` <br>
 /// Output: integer array `F ∈ Z^256_m`, where `m = 2^d if d < 12` and `m = q if d = 12`
-pub(crate) fn byte_decode(
-    d: u32, bytes_b: &[u8], integers_f: &mut [Z; 256],
-) -> Result<(), &'static str> {
+pub(crate) fn byte_decode(d: u32, bytes_b: &[u8]) -> Result<[Z; 256], &'static str> {
+    let mut integers_f = [Z::default(); 256];
     debug_assert_eq!(bytes_b.len(), 32 * d as usize, "Alg 6: bytes len is not 32 * d");
     //
     // Our "working" register
@@ -110,7 +109,7 @@ pub(crate) fn byte_decode(
     // Supports modulus check per FIPS 203 section 6.2.2
     let m = if d < 12 { 1 << d } else { u32::from(Q) };
     ensure!(integers_f.iter().all(|e| e.get_u32() < m), "Alg 6: integers out of range");
-    Ok(())
+    Ok(integers_f)
 }
 
 
@@ -130,13 +129,13 @@ mod tests {
     #[test]
     fn test_decode_and_encode() {
         let mut rng = rand_chacha::ChaCha8Rng::seed_from_u64(123);
-        let mut integer_array = [Z::default(); 256];
+        //let mut integer_array = [Z::default(); 256];
         for num_bits in 2..12_u32 {
             for _i in 0..100 {
                 let num_bytes = 32 * num_bits as usize;
                 let mut bytes2 = vec![0u8; num_bytes];
                 let bytes1: Vec<u8> = (0..num_bytes).map(|_| rng.gen()).collect();
-                byte_decode(num_bits, &bytes1, &mut integer_array).unwrap();
+                let integer_array = byte_decode(num_bits, &bytes1).unwrap();
                 byte_encode(num_bits, &integer_array, &mut bytes2);
                 assert_eq!(bytes1, bytes2);
             }
@@ -149,7 +148,7 @@ mod tests {
         let num_bits = 12;
         let num_bytes = 32 * num_bits as usize;
         let bytes1: Vec<u8> = (0..num_bytes).map(|_| 0xFF).collect();
-        let ret = byte_decode(num_bits, &bytes1, &mut integer_array);
+        let ret = byte_decode(num_bits, &bytes1);
         assert!(ret.is_err());
         integer_array.iter_mut().for_each(|x| x.set_u16(u16::MAX));
     }
